==> haskell-fourmolu-0.10.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.10.0.0
visibility:           public
id:                   fourmolu-0.10.0.0-E9cBXEH3lMPAMtYV3GRwh6
key:                  fourmolu-0.10.0.0-E9cBXEH3lMPAMtYV3GRwh6
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  e5ee97f4070dcaf52c8f3e61c778be99
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.TH Ormolu.Config.Types GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.10.0.0-E9cBXEH3lMPAMtYV3GRwh6
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-AZUE6X4VFrn1KwicRR603j
    MemoTrie-0.6.11-JJcTGYn6Kd6H0FEyClD75j
    aeson-2.1.2.1-KaceSWeAWkBK9urIr7RMHq
    ansi-terminal-1.0.2-EhzJoAzi53XHL1K3CBirLP array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-LsGlFZLL4kx9NfYo2s5ICp mtl-2.2.2
    syb-0.7.2.4-FxOA5ryuuOlLotDfjBKcFb template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-B7uVUMsyq8p3a6tDnL2f7O
    yaml-0.11.11.2-k5JnsslwX48CYsOhNsqzT

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fourmolu-0.10.0.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fourmolu
version:              0.10.0.0
visibility:           public
id:                   fourmolu-0.10.0.0-3SdGf4VSMfkDyiHkOwPRnL
key:                  fourmolu-0.10.0.0-3SdGf4VSMfkDyiHkOwPRnL
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>
    Brandon Chinn <brandonchinn178@gmail.com>

homepage:             https://github.com/fourmolu/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  f1609fd87d03cbfd708d7001f64c3074
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       Ormolu.Config.TH Ormolu.Config.Types GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fourmolu-0.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fourmolu
hs-libraries:         HSfourmolu-0.10.0.0-3SdGf4VSMfkDyiHkOwPRnL
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-5tiatjLd0Kd6kPxEAl95e4
    MemoTrie-0.6.11-BkWp590MYkB8VUtFS7LIOb
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-9jbfOTjnDTaHWZ1zNhDVr9 mtl-2.2.2
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-KIUCsf9wDCsIUCWtsfMOK9
    yaml-0.11.11.2-1BX8zrqeWicCfVb3vlAqfh

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
